NLSL: cscg.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Functions/Subroutines
cscg.f90 File Reference

Go to the source code of this file.

## Functions/Subroutines
subroutine | cscg (b, ndim, mxcgs, cgtol, shift, x, al, bl, ndone, error)

## Function/Subroutine Documentation

subroutine cscg | ( | complex*16, dimension(mxdim) | b,
|  | integer | ndim,
|  | integer | mxcgs,
|  | double precision | cgtol,
|  | complex*16 | shift,
|  | complex*16, dimension(mxdim) | x,
|  | complex*16, dimension(mxstep) | al,
|  | complex*16, dimension(mxstep) | bl,
|  | integer | ndone,
|  | double precision | error
| ) |  |

Definition at line 68 of file cscg.f90.

Here is the call graph for this function:

Here is the caller graph for this function: